@@ -3,15 +3,12 @@ package Data::HashType;
 use strict;
 use warnings;
 
+use DateTime;
 use Error::Pure qw(err);
 use Mo qw(build is);
-use Mo::utils 0.09 qw(check_bool check_isa check_length check_number check_required);
+use Mo::utils 0.09 qw(check_isa check_length check_number check_required);
 
-our $VERSION = 0.04;
-
-has active => (
-	is => 'ro',
-);
+our $VERSION = 0.05;
 
 has id => (
 	is => 'ro',
@@ -32,12 +29,6 @@ has valid_to => (
 sub BUILD {
 	my $self = shift;
 
-	# Check active.
-	if (! defined $self->{'active'}) {
-		$self->{'active'} = 1;
-	}
-	check_bool($self, 'active');
-
 	# Check id.
 	check_number($self, 'id');
 
@@ -46,8 +37,7 @@ sub BUILD {
 	check_length($self, 'name', 50);
 
 	# Check valid_from.
-	# XXX Add required in future.
-	# check_required($self, 'valid_from');
+	check_required($self, 'valid_from');
 	check_isa($self, 'valid_from', 'DateTime');
 
 	# Check valid_to.
@@ -81,7 +71,6 @@ Data::HashType - Data object for hash type.
  use Data::HashType;
 
  my $obj = Data::HashType->new(%params);
- my $active = $obj->active; # deprecated
  my $id = $obj->id;
  my $name = $obj->name;
  my $valid_from = $obj->valid_from;
@@ -107,14 +96,6 @@ Constructor.
 
 =over 8
 
-=item * C<active>
-
-B<Parameter 'active' will be removed. Use the C<valid_from/valid_to> parameter instead.>
-
-Flag for activity of hash type.
-Possible value is 0/1.
-Default value is 1 (active).
-
 =item * C<id>
 
 Id of record.
@@ -144,16 +125,6 @@ It's optional.
 
 Returns instance of object.
 
-=head2 C<active>
-
-B<Method 'active' will be removed. Use the L<valid_from>/L<valid_to> parameter instead.>
-
- my $active = $obj->active;
-
-Get active flag.
-
-Returns 0/1.
-
 =head2 C<id>
 
  my $id = $obj->id;
@@ -190,13 +161,12 @@ Returns L<DateTime> object or undef.
 
  new():
          From Mo::utils:
-                 Parameter 'active' must be a bool (0/1).
-                         Value: %s
                  Parameter 'id' must be a number.
                          Value: %s
                  Parameter 'name' has length greater than '50'.
                          Value: %s
                  Parameter 'name' is required.
+                 Parameter 'valid_from' is required.
                  Parameter 'valid_from' must be a 'DateTime' object.
                          Value: %s
                          Reference: %s
@@ -239,6 +209,7 @@ Returns L<DateTime> object or undef.
 
 =head1 DEPENDENCIES
 
+L<DateTime>,
 L<Error::Pure>,
 L<Mo>,
 L<Mo::utils>.
@@ -261,6 +232,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
